
/*

  Read a data file in the form generated by the propagator program,
  and convert it to a new format (suitable for reading by FORTRAN
  programs).

*/

#include <stdio.h>
#include "datahdr.h"
#include "strmhdr.h"
#include "fstrmhdr.h"

static char *usage        = "USAGE: convert <state> <infile> <outfile>\n" ;

extern void sums () ;

void get_params (state, file1, file2, argc, argv)
char **state, **file1, **file2 ;
int argc ;
char *argv [] ;
{
  if (argc != 4)
  {
    fprintf (stderr, usage) ;
    exit (1) ;
  }
  *state = argv [1] ;

  if (! strcmp (argv [2], "-"))
    *file1 = NULL ;
  else
    *file1 = argv [2] ;

  if (! strcmp (argv [3], "-"))
    *file2 = NULL ;
  else
    *file2 = argv [3] ;
}

void main (argc, argv)
int argc ;
char *argv [] ;
{
  char *state, *file1, *file2 ;
  DATA  *datas, *data1 ;
  FDATA *data2 ;
  int   params [NUM_STT_PARAMS + NUM_DAT_PARAMS] ;
  float coeffs [NUM_STT_COEFFS + NUM_DAT_COEFFS] ;
  int l_time, l_space ;

  get_params  (&state, &file1, &file2, argc, argv) ;

  datas = data_open_read (state) ;
  read_header (datas) ;
  read_coeffs (datas, coeffs) ;
  read_params (datas, params) ;
  data_close  (datas) ;

  data1 = data_open_read (file1) ;
  read_header (data1) ;
  read_coeffs (data1, coeffs + NUM_STT_COEFFS) ;
  read_params (data1, params + NUM_STT_PARAMS) ;

  data2 = fdata_open_write (file2) ;
  fdata_write_header (data2, NUM_STT_PARAMS + NUM_DAT_PARAMS, params,
                             NUM_STT_COEFFS + NUM_DAT_COEFFS, coeffs) ;

  fprintf (stderr, "%d\n", params [STT_L_T   ]) ;
  fprintf (stderr, "%d\n", params [NUM_STT_PARAMS + DAT_SC    ]) ;
  fprintf (stderr, "%f\n", coeffs [NUM_STT_COEFFS + DAT_K_FERM]) ;
  fprintf (stderr, "\n") ;

  l_time  = params [STT_L_T] ;
  l_space = params [STT_L_X] * params [STT_L_Y] * params [STT_L_Z] ;

  read_field_begin (data1) ;
  fdata_write_field_begin (data2) ;
  convert (data1, data2, l_time, l_space) ;
  fdata_write_field_end   (data2) ;

  data_close  (data1) ;
  fdata_close (data2) ;
}

